class ApplicationController < ActionController::Base
  # Prevent CSRF attacks by raising an exception.
  # For APIs, you may want to use :null_session instead.
  protect_from_forgery with: :null_session
  before_action :configure_permitted_parameters, if: :devise_controller?

  def repository
    Portalmec::Application.repository
  end

  protected

  def configure_permitted_parameters
    registration_params = [:name, :email, :avatar, :password, :password_confirmation]

    if params[:action] == 'update'
      devise_parameter_sanitizer.for(:account_update) {
          |u| u.permit(registration_params << :current_password)
      }
    elsif params[:action] == 'create'
      devise_parameter_sanitizer.for(:sign_up) {
          |u| u.permit(registration_params)
      }
    end
  end

  def dspace_service
    @dspace_service ||= DspaceService.new(
        DspaceService.create_dspace_client(
            Rails.application.secrets.dspace_host,
            get_dspace_authenticable_token
        )
    )
  end

  def get_dspace_authenticable_token
    session[:dspace_auth_token] || nil
  end

end
