class Search::SolrController < ApplicationController

  def search
    queryParams = {:q => '*:*', :fq => params[:qry]}

    results = solr_client.get 'select',
                              :params => merge_search_parameters(queryParams, solr_search_default_parameters)

    objectsFound1 = select_items_from_results(results)
    #@numFound = results["response"]["numFound"]
    @numFound =objectsFound1.length

    per_page=10
    @npagnac=10
    if(params[:paginacao])
      per_page=params[:paginacao].to_i
      @npagnac=per_page
    end

    if(params[:page])
      #params[:page] = 1
    else
      params[:page] = 1
    end

    current_page= params[:page].to_i

    if params[:sort]
      @ordena=params[:sort]
    end
    if params[:sort] == "author"
      objectsFound1 = sort_author(objectsFound1);
    elsif params[:sort] == "publicationasc"
      objectsFound1 = objectsFound1.sort_by{|item| [ item['search.resourceid'] ]}
    elsif params[:sort] == "publicationdesc"
      objectsFound1 = objectsFound1.sort_by{|item| -item['search.resourceid'] }
    elsif params[:sort] == "relevance"
      items= objectsFound1.collect{ |x| Ranking::Item.new("",1,1,1, x)  } #puts each object in an item

      rater = Ranking::Rater.new(
          Ranking::Strategies::BasicRater.new(
              #define sorting weights
              positionWeight = 1000,
              useWeight = 1,
              likeWeight = 100
          )
      )

      a = rater.sortByRate(items) # Returns sorted array of items
      objectsFound1= a.collect{ |x|  x.info  } #get only the info fields(objects)

    elsif params[:sort] == "title"
      objectsFound1 = sort_title(objectsFound1);
    end
    #    current_page, per_page, total_results
    @objectsFound = WillPaginate::Collection.create(current_page, per_page, objectsFound1.length) do |pager|
      @start = (current_page-1)*per_page
      pager.replace (objectsFound1.to_a[@start,per_page])
    end

    #search.resourceid
    #for item in objectsFound
    #   Busca no orientDb (rid,classe,rate)
    #end
  end

  private

  #Resource types:
  # 2 = Item
  # 3 = Collection
  # 4 = Community

  def select_items_from_results(results)
    resultList = Set.new
    results["response"]["docs"].select { |r|
      r["search.resourcetype"].to_i.equal? 2
    }.each do |i|
      resultList.add i
    end
    return resultList
  end

  def solr_client
    return RSolr.connect :url => 'http://portalmecdev.c3sl.ufpr.br:8080/solr/search/'
  end

  def merge_search_parameters(p1, p2)
    return p1.merge(p2) { |key,oldval,newval| key = [newval,oldval].flatten }
  end

  def solr_search_default_parameters
    return {
        "fl"=>["
        search.resourcetype, search.resourceid,
        handle, author, title, dc.description
      "],
        "type"=>"0",
        "start"=>"0",
        "rows"=>"1000",
        "facet"=>"true",
        "facet.offset"=>"0",
        "facet.mincount"=>"1",
        "f.subject_tax_0_filter.facet.sort"=>"count",
        "f.subject_tax_0_filter.facet.limit"=>"11",
        "f.author_filter.facet.limit"=>"11",
        "f.dateIssued.year.facet.sort"=>"index",
        "f.dateIssued.year.facet.limit"=>"10",
        "f.author_filter.facet.sort"=>"count",
        "facet.field"=>["author_filter","subject_tax_0_filter","dateIssued.year"],
        "fq"=>["NOT(withdrawn:true)","NOT(discoverable:false)","read:(g0 OR g0)"]
    }
  end

  def sort_author(items)
    items = items.sort_by{|item| [ item['author'].to_s.downcase ]}
    items.each{ |item| item['author'] = sort_author(item['author']) if (item['author'].nil? ? [] : item['author']).size > 0 }
    items
  end


  def sort_title(items)
    items = items.sort_by{|item| [ item['title'].to_s.downcase ]}
    items.each{ |item| item['title'] = sort_title(item['title']) if (item['title'].nil? ? [] : item['title']).size > 0 }
    items
  end
end