# For now, the User model is being persisted in two repositories:
#   * On postgres, using ActiveRecord
#   * OrientDb as graph nodes
#
# Goals: Keep the users in both (postgres, orientdb)
#
#               Devise Controllers -----> User model (with active record api)
#              /
#     Client -/
#             \
#              \
#               Portal Mec Controllers -> User repository
#
# How works?
#   For keep simple, user node in orientdb stored only a reference to the real user in postgres.
#   So, the user node will be only created or destroyed.
#
#    When devise create user, the active record hooks will sync with user repository
#    And, when the application call the user repository, it will keep sync with active record user model
class User < ActiveRecord::Base
  # Include default devise modules. Others available are:
  # :confirmable, :lockable, :timeoutable and :omniauthable
  devise :database_authenticatable, :registerable,
         :recoverable, :rememberable, :trackable, :validatable
  has_and_belongs_to_many :roles
  after_create SyncUserRepositoryService.new
  after_destroy SyncUserRepositoryService.new

  has_attached_file :avatar, styles: { medium: "300x300>", thumb: "60x60>" }, default_url: ActionController::Base.helpers.asset_path('missing.svg')
  validates_attachment_content_type :avatar, content_type: /\Aimage\/.*\Z/
end
